@@ -310,6 +310,11 @@ class datetimeComponent(Component):
         dt = self._fromisoformat(self.raw_value)
         return dt
 
+    def to_date(self):
+        if not self.raw_value:
+            return None
+        return self.to_datetime().date()
+
 
 class timeComponent(Component):
     pass
